[llvm-commits] CVS: nightlytest-serverside/NightlyTester.php

Patrick Jenkins pjenkins at apple.com
Thu Aug 17 13:47:47 PDT 2006



Changes in directory nightlytest-serverside:

NightlyTester.php updated: 1.14 -> 1.15
---
Log message:

Changed the definition for "Machines With Recent Submissions" from a 
machine that has submitted within the last month to a machine that has 
submitted in the last fourteen days.



---
Diffs of the changes:  (+18 -2)

 NightlyTester.php |   20 ++++++++++++++++++--
 1 files changed, 18 insertions(+), 2 deletions(-)


Index: nightlytest-serverside/NightlyTester.php
diff -u nightlytest-serverside/NightlyTester.php:1.14 nightlytest-serverside/NightlyTester.php:1.15
--- nightlytest-serverside/NightlyTester.php:1.14	Wed Aug  2 18:29:59 2006
+++ nightlytest-serverside/NightlyTester.php	Thu Aug 17 15:47:26 2006
@@ -48,7 +48,7 @@
  *
  *****************************************************/
 function getRecentMachineResource($mysql_link){
-  $night_query = mysql_query("SELECT machine FROM night where DATE_SUB(NOW(), INTERVAL 1 MONTH) <= added") or die (mysql_error());
+  $night_query = mysql_query("SELECT machine FROM night where DATE_SUB(NOW(), INTERVAL 14 DAY) <= added") or die (mysql_error());
   $machines="where id=0";
   $machine_arr = array();
   while($row = mysql_fetch_array($night_query)){
@@ -104,7 +104,8 @@
 
 /*****************************************************
  *
  * Purpose: Get the nights associated with a specific machine
  * Returns: A mysql query resource. Basically something you cal
  *          mysql_fetch_array on.
  *
@@ -116,6 +117,21 @@
 
 /*****************************************************
  *
+ * Purpose: Get the history of nights given a night and 
+ *          specific machine 
+ * Returns: A mysql query resource. Basically something you cal
+ *          mysql_fetch_array on.
+ *
+ *****************************************************/
+function getSuccessfulNightsHistory($machine_id, $mysql_link, $night_id, $order="DESC"){
+  $query="SELECT * FROM night WHERE machine=$machine_id and id<=$night_id and buildstatus=\"OK\" order by added $order";
+  $query = mysql_query($query) or die (mysql_error());
+  return $query;
+}
+
+
+/*****************************************************
+ *
  * Purpose: Get all the tests in the last $hours hours
  * Returns: A mysql query resource.
  *
@@ -104,7 +104,8 @@
 /*****************************************************
  *
- * Purpose: Get the nights associated with a specific machine
+ * Purpose: Get the nights associated with a specific machine for
+ *          which buildstatus is "OK"
  * Returns: A mysql query resource. Basically something you cal
  *          mysql_fetch_array on.






More information about the llvm-commits mailing list